# -*- coding:utf-8 -*-

import os
# from worklib.config import initConfig
def get_udid(executable_path_dict):
	return [i.split("\t")[0].strip() for i in os.popen(executable_path_dict["adb_path"] + "  devices").readlines() if
			"device" in i and "attached" not in i]

class adb(object):
	def __init__(self, udid,initConfigParams):

		self.config = initConfigParams
		self.adb_cmd = self.init_adb_cmd()
		self.aapt_path = self.init_aapt_cmd()

		# self.app_path = initConfigParams["app_path"]
		self.udid = udid

	def init_adb_cmd(self):
		if "adb_path" in self.config.keys():
			return self.config["adb_path"]
		else:
			return "adb"

	def init_aapt_cmd(self):
		if "aapt_path" in self.config.keys():
			return self.config["aapt_path"]
		else:
			return "aapt"

	def command(self, cmd):
		print(type(cmd))
		print(type(self.adb_cmd))
		print()
		text = self.adb_cmd + " -s " + self.udid + "  " + cmd
		print("--adb log------->"+text)
		return os.popen(text).read()

	def install_app(self, path):
		return self.command("install -t" + path)

	def query_system_packagelist(self, ):
		return self.command("shell pm list packages -f")

	def pull(self, systempath, localpath):
		return self.command("pull " + systempath + " " + localpath)

	def push(self, localpath, systempath):
		return self.command("push " + localpath + " " + systempath)

	def logcat(self, savelogpath, level=""):
		self.command("logcat %s  >" % (level) + savelogpath)

	def bugreport(self, savelogpath):

		self.command("bugreport >" + savelogpath)

	def monkey(self, cmd, savelogpath):
		self.command("shell monkey " + cmd + " >" + savelogpath)

	def ps(self, ps_cmd=""):
		return self.command("shell ps " + ps_cmd)

	def kill(self, port):
		self.command("shell kill " + port)

	def get_app_package(self,app_path):
		if os.name == "posix":
			aapt_dump = "%s dump badging %s |grep %s|awk '{print $2}'"
			appPackage = str(os.popen(aapt_dump % (self.aapt_path, app_path, "package")).read()).strip()[6:-1]
			# print(aapt_dump % (aapt_path,app_path, "launchable-activity"))
			try:
				appActivity = str(
					os.popen(aapt_dump % (self.aapt_path, app_path, "launchable-activity")).read()).split()[
								  0].strip()[6:-1]
			except Exception as e:
				appActivity = appPackage + ".main.MainActivity"

		elif os.name == "nt":
			appPackage = os.popen('aapt dump badging  %s |findStr "package:" ' % (app_path)).read().split(" ")[
							 1].strip()[6:-1]
			try:
				appActivity = \
					os.popen('aapt dump badging %s |findStr "launchable-activity"' % (app_path)).read().split(" ")[
						1].strip()[
					6:-1]
			except:
				appActivity = appPackage + ".main.MainActivity"

		return appPackage,appActivity

	def uninstall(self, app_path):
		self.command("uninstall " + self.get_app_package(app_path)[0])

	def dumpsys(self, dumpsys_cmd=""):
		return self.command("shell dumpsys " + dumpsys_cmd)

	def get_meninfo(self,app_path):
		return self.dumpsys("meninfo " + self.get_app_package(app_path)[0])

	def get_app_activity(self):
		pass


if __name__ == '__main__':
	executable_path_dict = {"adb_path": "/Users/zhenghong/Library/Android/sdk/platform-tools/adb",
							"aapt_path": "/Users/zhenghong/Library/Android/sdk/build-tools/29.0.3/aapt",
							"firefoxdriver": "/Users/zhenghong/work/gitee/AutomationFramework/conf/geckodriver",
							"chromedriver": "/Users/zhenghong/work/gitee/AutomationFramework/conf/chromedriver",
							"app_path":"/Users/zhenghong/Downloads/1fdb0cf17de2a5738f9c9789aae036f7.apk"}

	udid = get_udid(executable_path_dict)[0]
	print("udid",udid)
	adb = adb(udid,executable_path_dict)
	# adb.install_app(executable_path_dict["app_path"])
	print(adb.get_meninfo(executable_path_dict["app_path"]))

	pass





#-*- coding:utf-8 -*-
import json
import requests

class ding(object):
    def __init__(self,token):
        self.url = "https://oapi.dingtalk.com/robot/send?access_token=%s" % token

    def dingtalkself(self,msgtype=None,post_string=None, at_mobiles=None,isAtAll="false"):
        data = {
            'msgtype': msgtype,msgtype:post_string,
            "at": {"atMobiles": at_mobiles, "isAtAll":isAtAll}
        }
        # if post_string != None:
        #     data.update(post_string)
        print(data)
        print(self.url)
        response = requests.post(self.url,json=data)

    def send_text(self,post_string=None, at_mobiles=None,isAtAll="false"):
        text = {
            "content": str(post_string)
            }
        self.dingtalkself("text",text,at_mobiles,isAtAll)

    def send_markdown(self,post_string=None, at_mobiles=None,isAtAll="false"):
        text ={
             "title":"title",
             "text":post_string
             }
        self.dingtalkself("markdown",text,at_mobiles,isAtAll)

    def send_actionCard(self,title="没有设置标题",post_string=None, at_mobiles=None,isAtAll="false"):
        text ={
             "title":title,
             "text":post_string}
        self.dingtalkself("actionCard",text,at_mobiles,isAtAll)

    def send_feedCard(self,post_string=None, at_mobiles=None,isAtAll="false"):
        text ={"links":post_string}
        self.dingtalkself("feedCard",text,at_mobiles,isAtAll)


if __name__ == '__main__':
    token = ''
    ding = ding(token)
    ding.send_text("cache:sfdsfjaklcache")
    ding.send_markdown("cache:#### 杭州天气 @156xxxx8827\n" +
                 "> 9度，西北风1级，空气良89，相对温度73%\n\n" +
                 "> ![screenshot](https://gw.alicdn.com/tfs/TB1ut3xxbsrBKNjSZFpXXcXhFXa-846-786.png)\n"  +
                 "> #####   # 10点20分发布 [天气](http://www.thinkpage.cn/) ")
    actionCard ='''cache
    "![screenshot](@lADOpwk3K80C0M0FoA) 
 ### 乔布斯 20 年前想打造的苹果咖啡厅 
 Apple Store 的设计正从原来满满的科技感走向生活化，而其生活化的走向其实可以追溯到 20 年前苹果一个建立咖啡馆的计划", 
        "hideAvatar": "0", 
        "btnOrientation": "0", 
        "singleTitle" : "阅读全文",
        "singleURL" : "https://www.dingtalk.com/"
    '''
    ding.send_actionCard("cache",actionCard)

    feedCard = [
            {
                "title": "测试报告",
                "messageURL": "https://www.dingtalk.com/s?__biz=MzA4NjMwMTA2Ng==&mid=2650316842&idx=1&sn=60da3ea2b29f1dcc43a7c8e4a7c97a16&scene=2&srcid=09189AnRJEdIiWVaKltFzNTw&from=timeline&isappinstalled=0&key=&ascene=2&uin=&devicetype=android-23&version=26031933&nettype=WIFI",
                "picURL": "https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=3514361501,3291815511&fm=26&gp=0.jpg",
                "text": "chache测试报告",

            },
            {
                "title": "测试计划",
                "messageURL": "https://www.dingtalk.com/s?__biz=MzA4NjMwMTA2Ng==&mid=2650316842&idx=1&sn=60da3ea2b29f1dcc43a7c8e4a7c97a16&scene=2&srcid=09189AnRJEdIiWVaKltFzNTw&from=timeline&isappinstalled=0&key=&ascene=2&uin=&devicetype=android-23&version=26031933&nettype=WIFI",
                "picURL": "https://ss0.bdstatic.com/70cFuHSh_Q1YnxGkpoWK1HF6hhy/it/u=3514361501,3291815511&fm=26&gp=0.jpg"
            },
            {
                "title": "适配测试计划",
                "messageURL": "https://www.dingtalk.com/s?__biz=MzA4NjMwMTA2Ng==&mid=2650316842&idx=1&sn=60da3ea2b29f1dcc43a7c8e4a7c97a16&scene=2&srcid=09189AnRJEdIiWVaKltFzNTw&from=timeline&isappinstalled=0&key=&ascene=2&uin=&devicetype=android-23&version=26031933&nettype=WIFI",
                "picURL": "https://www.dingtalk.com/"
            },
            {
                "title": "monkey测试计划",
                "messageURL": "https://www.dingtalk.com/s?__biz=MzA4NjMwMTA2Ng==&mid=2650316842&idx=1&sn=60da3ea2b29f1dcc43a7c8e4a7c97a16&scene=2&srcid=09189AnRJEdIiWVaKltFzNTw&from=timeline&isappinstalled=0&key=&ascene=2&uin=&devicetype=android-23&version=26031933&nettype=WIFI",
                "picURL": "https://www.dingtalk.com/"
            },
            {
                "title": "测试总结与回顾",
                "messageURL": "https://www.dingtalk.com/s?__biz=MzA4NjMwMTA2Ng==&mid=2650316842&idx=1&sn=60da3ea2b29f1dcc43a7c8e4a7c97a16&scene=2&srcid=09189AnRJEdIiWVaKltFzNTw&from=timeline&isappinstalled=0&key=&ascene=2&uin=&devicetype=android-23&version=26031933&nettype=WIFI",
                "picURL": "https://www.dingtalk.com/"
            }
        ]
    ding.send_feedCard(feedCard)





import requests

d= {
    "feedCard": {
        "links": [
            {
                "title": "cache时代的火车向前开",
                "messageURL": "https://www.dingtalk.com/s?__biz=MzA4NjMwMTA2Ng==&mid=2650316842&idx=1&sn=60da3ea2b29f1dcc43a7c8e4a7c97a16&scene=2&srcid=09189AnRJEdIiWVaKltFzNTw&from=timeline&isappinstalled=0&key=&ascene=2&uin=&devicetype=android-23&version=26031933&nettype=WIFI",
                "picURL": "https://www.dingtalk.com/"
            },
            {
                "title": "cache时代的火车向前开2",
                "messageURL": "https://www.dingtalk.com/s?__biz=MzA4NjMwMTA2Ng==&mid=2650316842&idx=1&sn=60da3ea2b29f1dcc43a7c8e4a7c97a16&scene=2&srcid=09189AnRJEdIiWVaKltFzNTw&from=timeline&isappinstalled=0&key=&ascene=2&uin=&devicetype=android-23&version=26031933&nettype=WIFI",
                "picURL": "https://www.dingtalk.com/"
            }
        ]
    },
    "msgtype": "feedCard"
}

requests.post("https://oapi.dingtalk.com/robot/send?access_token=15b1970b17a79da13619df46e1b4bd6072f23c7e0ab3ed4fb0941ae9ee1482bd",json=d)



#-*- coding:utf-8 -*-
import setuptools

with open("README.md","r") as file:
	long_description = file.read()

setuptools.setup(
	name="worklib",
	version="0.0.1",
	author="lzh",
	author_email="743872668@qq.com",
	description=long_description,
	long_description_content_type="text/markdown",
	url="",
	packages=setuptools.find_packages(),
	classfiers=[""]

)
